summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/spells4.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/spells4.cc')
-rw-r--r--crawl-ref/source/spells4.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/crawl-ref/source/spells4.cc b/crawl-ref/source/spells4.cc
index 50173cae75..9438a89b6e 100644
--- a/crawl-ref/source/spells4.cc
+++ b/crawl-ref/source/spells4.cc
@@ -329,18 +329,18 @@ void cast_shatter(int pow)
mpr("Ka-crash!", MSGCH_SOUND);
}
-// Cast_forescry: raises evasion (by 8 currently) via Divinations.
-void cast_forescry(int pow)
+// Cast_phase_shift: raises evasion (by 8 currently) via Translocations.
+void cast_phase_shift(int pow)
{
- if (!you.duration[DUR_FORESCRY])
- mpr("You begin to receive glimpses of the immediate future...");
+ if (!you.duration[DUR_PHASE_SHIFT])
+ mpr("You begin to phase in and out of the material plane...");
else
- mpr("Your vision of the future intensifies.");
+ mpr("Your phasing becomes more pronounced.");
- you.duration[DUR_FORESCRY] += 5 + random2(pow);
+ you.duration[DUR_PHASE_SHIFT] += 5 + random2(pow);
- if (you.duration[DUR_FORESCRY] > 30)
- you.duration[DUR_FORESCRY] = 30;
+ if (you.duration[DUR_PHASE_SHIFT] > 30)
+ you.duration[DUR_PHASE_SHIFT] = 30;
you.redraw_evasion = true;
}